@@ -1,11 +1,14 @@
-
 use crate::Route;
 
-
 pub struct AssetPlatforms {
-    endpoint: String,                  // /asset/platforms
+    endpoint: String,
 }
 
+impl AssetPlatforms {
+    pub fn required() -> AssetPlatforms {
+        Default::default()
+    }
+}
 
 impl Default for AssetPlatforms {
     fn default() -> AssetPlatforms {
@@ -14,6 +17,7 @@ impl Default for AssetPlatforms {
         }
     }
 }
+
 impl Route for AssetPlatforms {
     fn api_endpoint(&self) -> String {
         format!("{}", self.endpoint)
