@@ -1,14 +1,23 @@
-
 use crate::Route;
 
 pub struct List {
-    endpoint: String,                   // /coins/categories/list
+    endpoint: String,
 }
 
 pub struct Categories {
-    endpoint: String,                   // /coin/categories
+    endpoint: String,
 }
 
+impl List {
+    pub fn required() -> List {
+        List::default()
+    }
+}
+impl Categories {
+    pub fn required() -> Categories {
+        Categories::default()
+    }
+}
 
 impl Default for List {
     fn default() -> List {
@@ -20,12 +29,11 @@ impl Default for List {
 impl Default for Categories {
     fn default() -> Categories {
         Categories {
-            endpoint: String::from("/coin/categories"),
+            endpoint: String::from("/coins/categories"),
         }
     }
 }
 
-
 impl Route for List {
     fn api_endpoint(&self) -> String {
         format!("{}", self.endpoint)
