@@ -1,8 +1,17 @@
 use crate::Route;
 
 pub struct Companies {
-    endpoint: String,               // /companies/public_treasury/{coin_id}
-    pub coin_id: String,            // bitcoin or ethereum
+    endpoint: String,
+    pub coin_id: String,
+}
+
+impl Companies {
+    pub fn required(coin_id: String) -> Companies {
+        Companies {
+            coin_id,
+            ..Default::default()
+        }
+    }
 }
 
 impl Default for Companies {
@@ -13,6 +22,7 @@ impl Default for Companies {
         }
     }
 }
+
 impl Route for Companies {
     fn api_endpoint(&self) -> String {
         let endpoint = self.endpoint.replace("COIN_ID", &(self.coin_id));
@@ -21,5 +31,4 @@ impl Route for Companies {
     fn query_string(&self) -> String {
         String::from("")
     }
-
 }
