@@ -1,7 +1,13 @@
 use crate::Route;
 
 pub struct ExchangeRates {
-    endpoint: String,           // /exchange_rates
+    endpoint: String, // /exchange_rates
+}
+
+impl ExchangeRates {
+    pub fn required() -> ExchangeRates {
+        ExchangeRates::default()
+    }
 }
 
 impl Default for ExchangeRates {
