@@ -1,12 +1,23 @@
 use crate::Route;
 
 pub struct Global {
-    endpoint: String,               // /global
+    endpoint: String, // /global
 }
 pub struct DeFi {
     endpoint: String,
 }
 
+impl Global {
+    pub fn required() -> Global {
+        Global::default()
+    }
+}
+impl DeFi {
+    pub fn required() -> DeFi {
+        DeFi::default()
+    }
+}
+
 impl Default for Global {
     fn default() -> Global {
         Global {
@@ -17,7 +28,7 @@ impl Default for Global {
 impl Default for DeFi {
     fn default() -> DeFi {
         DeFi {
-            endpoint: String::from("/global/decentralized_finance_defi")
+            endpoint: String::from("/global/decentralized_finance_defi"),
         }
     }
 }
