@@ -1,7 +1,13 @@
 use crate::Route;
 
 pub struct Trending {
-    endpoint: String,               // /search/trending
+    endpoint: String, // /search/trending
+}
+
+impl Trending {
+    pub fn required() -> Trending {
+        Trending::default()
+    }
 }
 
 impl Default for Trending {
